@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -69,7 +69,7 @@ __all__ = ("SWFClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -90,7 +90,7 @@ class Exceptions:
 
 class SWFClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html)
     """
 
@@ -106,7 +106,7 @@ class SWFClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#can_paginate)
         """
 
@@ -114,18 +114,18 @@ class SWFClient(BaseClient):
         self,
         *,
         domain: str,
-        startTimeFilter: "ExecutionTimeFilterTypeDef" = None,
-        closeTimeFilter: "ExecutionTimeFilterTypeDef" = None,
-        executionFilter: "WorkflowExecutionFilterTypeDef" = None,
-        typeFilter: "WorkflowTypeFilterTypeDef" = None,
-        tagFilter: "TagFilterTypeDef" = None,
-        closeStatusFilter: "CloseStatusFilterTypeDef" = None
+        startTimeFilter: "ExecutionTimeFilterTypeDef" = ...,
+        closeTimeFilter: "ExecutionTimeFilterTypeDef" = ...,
+        executionFilter: "WorkflowExecutionFilterTypeDef" = ...,
+        typeFilter: "WorkflowTypeFilterTypeDef" = ...,
+        tagFilter: "TagFilterTypeDef" = ...,
+        closeStatusFilter: "CloseStatusFilterTypeDef" = ...
     ) -> WorkflowExecutionCountTypeDef:
         """
         Returns the number of closed workflow executions within the given domain that
         meet the specified filtering criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.count_closed_workflow_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.count_closed_workflow_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#count_closed_workflow_executions)
         """
 
@@ -134,15 +134,15 @@ class SWFClient(BaseClient):
         *,
         domain: str,
         startTimeFilter: "ExecutionTimeFilterTypeDef",
-        typeFilter: "WorkflowTypeFilterTypeDef" = None,
-        tagFilter: "TagFilterTypeDef" = None,
-        executionFilter: "WorkflowExecutionFilterTypeDef" = None
+        typeFilter: "WorkflowTypeFilterTypeDef" = ...,
+        tagFilter: "TagFilterTypeDef" = ...,
+        executionFilter: "WorkflowExecutionFilterTypeDef" = ...
     ) -> WorkflowExecutionCountTypeDef:
         """
         Returns the number of open workflow executions within the given domain that meet
         the specified filtering criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.count_open_workflow_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.count_open_workflow_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#count_open_workflow_executions)
         """
 
@@ -152,7 +152,7 @@ class SWFClient(BaseClient):
         """
         Returns the estimated number of activity tasks in the specified task list.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.count_pending_activity_tasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.count_pending_activity_tasks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#count_pending_activity_tasks)
         """
 
@@ -162,7 +162,7 @@ class SWFClient(BaseClient):
         """
         Returns the estimated number of decision tasks in the specified task list.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.count_pending_decision_tasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.count_pending_decision_tasks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#count_pending_decision_tasks)
         """
 
@@ -170,7 +170,7 @@ class SWFClient(BaseClient):
         """
         Deprecates the specified *activity type*.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.deprecate_activity_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.deprecate_activity_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#deprecate_activity_type)
         """
 
@@ -178,7 +178,7 @@ class SWFClient(BaseClient):
         """
         Deprecates the specified domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.deprecate_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.deprecate_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#deprecate_domain)
         """
 
@@ -186,7 +186,7 @@ class SWFClient(BaseClient):
         """
         Deprecates the specified *workflow type*.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.deprecate_workflow_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.deprecate_workflow_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#deprecate_workflow_type)
         """
 
@@ -196,7 +196,7 @@ class SWFClient(BaseClient):
         """
         Returns information about the specified activity type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.describe_activity_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.describe_activity_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#describe_activity_type)
         """
 
@@ -205,7 +205,7 @@ class SWFClient(BaseClient):
         Returns information about the specified domain, including description and
         status.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.describe_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.describe_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#describe_domain)
         """
 
@@ -216,7 +216,7 @@ class SWFClient(BaseClient):
         Returns information about the specified workflow execution including its type
         and some statistics.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.describe_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.describe_workflow_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#describe_workflow_execution)
         """
 
@@ -226,21 +226,21 @@ class SWFClient(BaseClient):
         """
         Returns information about the specified *workflow type*.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.describe_workflow_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.describe_workflow_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#describe_workflow_type)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#generate_presigned_url)
         """
 
@@ -249,14 +249,14 @@ class SWFClient(BaseClient):
         *,
         domain: str,
         execution: "WorkflowExecutionTypeDef",
-        nextPageToken: str = None,
-        maximumPageSize: int = None,
-        reverseOrder: bool = None
+        nextPageToken: str = ...,
+        maximumPageSize: int = ...,
+        reverseOrder: bool = ...
     ) -> HistoryTypeDef:
         """
         Returns the history of the specified workflow execution.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.get_workflow_execution_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.get_workflow_execution_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#get_workflow_execution_history)
         """
 
@@ -265,16 +265,16 @@ class SWFClient(BaseClient):
         *,
         domain: str,
         registrationStatus: RegistrationStatusType,
-        name: str = None,
-        nextPageToken: str = None,
-        maximumPageSize: int = None,
-        reverseOrder: bool = None
+        name: str = ...,
+        nextPageToken: str = ...,
+        maximumPageSize: int = ...,
+        reverseOrder: bool = ...
     ) -> ActivityTypeInfosTypeDef:
         """
         Returns information about all activities registered in the specified domain that
         match the specified name and registration status.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.list_activity_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.list_activity_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#list_activity_types)
         """
 
@@ -282,21 +282,21 @@ class SWFClient(BaseClient):
         self,
         *,
         domain: str,
-        startTimeFilter: "ExecutionTimeFilterTypeDef" = None,
-        closeTimeFilter: "ExecutionTimeFilterTypeDef" = None,
-        executionFilter: "WorkflowExecutionFilterTypeDef" = None,
-        closeStatusFilter: "CloseStatusFilterTypeDef" = None,
-        typeFilter: "WorkflowTypeFilterTypeDef" = None,
-        tagFilter: "TagFilterTypeDef" = None,
-        nextPageToken: str = None,
-        maximumPageSize: int = None,
-        reverseOrder: bool = None
+        startTimeFilter: "ExecutionTimeFilterTypeDef" = ...,
+        closeTimeFilter: "ExecutionTimeFilterTypeDef" = ...,
+        executionFilter: "WorkflowExecutionFilterTypeDef" = ...,
+        closeStatusFilter: "CloseStatusFilterTypeDef" = ...,
+        typeFilter: "WorkflowTypeFilterTypeDef" = ...,
+        tagFilter: "TagFilterTypeDef" = ...,
+        nextPageToken: str = ...,
+        maximumPageSize: int = ...,
+        reverseOrder: bool = ...
     ) -> WorkflowExecutionInfosTypeDef:
         """
         Returns a list of closed workflow executions in the specified domain that meet
         the filtering criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.list_closed_workflow_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.list_closed_workflow_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#list_closed_workflow_executions)
         """
 
@@ -304,14 +304,14 @@ class SWFClient(BaseClient):
         self,
         *,
         registrationStatus: RegistrationStatusType,
-        nextPageToken: str = None,
-        maximumPageSize: int = None,
-        reverseOrder: bool = None
+        nextPageToken: str = ...,
+        maximumPageSize: int = ...,
+        reverseOrder: bool = ...
     ) -> DomainInfosTypeDef:
         """
         Returns the list of domains registered in the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.list_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.list_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#list_domains)
         """
 
@@ -320,18 +320,18 @@ class SWFClient(BaseClient):
         *,
         domain: str,
         startTimeFilter: "ExecutionTimeFilterTypeDef",
-        typeFilter: "WorkflowTypeFilterTypeDef" = None,
-        tagFilter: "TagFilterTypeDef" = None,
-        nextPageToken: str = None,
-        maximumPageSize: int = None,
-        reverseOrder: bool = None,
-        executionFilter: "WorkflowExecutionFilterTypeDef" = None
+        typeFilter: "WorkflowTypeFilterTypeDef" = ...,
+        tagFilter: "TagFilterTypeDef" = ...,
+        nextPageToken: str = ...,
+        maximumPageSize: int = ...,
+        reverseOrder: bool = ...,
+        executionFilter: "WorkflowExecutionFilterTypeDef" = ...
     ) -> WorkflowExecutionInfosTypeDef:
         """
         Returns a list of open workflow executions in the specified domain that meet the
         filtering criteria.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.list_open_workflow_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.list_open_workflow_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#list_open_workflow_executions)
         """
 
@@ -339,7 +339,7 @@ class SWFClient(BaseClient):
         """
         List tags for a given domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#list_tags_for_resource)
         """
 
@@ -348,25 +348,25 @@ class SWFClient(BaseClient):
         *,
         domain: str,
         registrationStatus: RegistrationStatusType,
-        name: str = None,
-        nextPageToken: str = None,
-        maximumPageSize: int = None,
-        reverseOrder: bool = None
+        name: str = ...,
+        nextPageToken: str = ...,
+        maximumPageSize: int = ...,
+        reverseOrder: bool = ...
     ) -> WorkflowTypeInfosTypeDef:
         """
         Returns information about workflow types in the specified domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.list_workflow_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.list_workflow_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#list_workflow_types)
         """
 
     def poll_for_activity_task(
-        self, *, domain: str, taskList: "TaskListTypeDef", identity: str = None
+        self, *, domain: str, taskList: "TaskListTypeDef", identity: str = ...
     ) -> ActivityTaskTypeDef:
         """
         Used by workers to get an  ActivityTask from the specified activity `taskList`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.poll_for_activity_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.poll_for_activity_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#poll_for_activity_task)
         """
 
@@ -375,26 +375,26 @@ class SWFClient(BaseClient):
         *,
         domain: str,
         taskList: "TaskListTypeDef",
-        identity: str = None,
-        nextPageToken: str = None,
-        maximumPageSize: int = None,
-        reverseOrder: bool = None
+        identity: str = ...,
+        nextPageToken: str = ...,
+        maximumPageSize: int = ...,
+        reverseOrder: bool = ...
     ) -> DecisionTaskTypeDef:
         """
         Used by deciders to get a  DecisionTask from the specified decision `taskList`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.poll_for_decision_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.poll_for_decision_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#poll_for_decision_task)
         """
 
     def record_activity_task_heartbeat(
-        self, *, taskToken: str, details: str = None
+        self, *, taskToken: str, details: str = ...
     ) -> ActivityTaskStatusTypeDef:
         """
         Used by activity workers to report to the service that the  ActivityTask
         represented by the specified `taskToken` is still making progress.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.record_activity_task_heartbeat)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.record_activity_task_heartbeat)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#record_activity_task_heartbeat)
         """
 
@@ -404,19 +404,19 @@ class SWFClient(BaseClient):
         domain: str,
         name: str,
         version: str,
-        description: str = None,
-        defaultTaskStartToCloseTimeout: str = None,
-        defaultTaskHeartbeatTimeout: str = None,
-        defaultTaskList: "TaskListTypeDef" = None,
-        defaultTaskPriority: str = None,
-        defaultTaskScheduleToStartTimeout: str = None,
-        defaultTaskScheduleToCloseTimeout: str = None
+        description: str = ...,
+        defaultTaskStartToCloseTimeout: str = ...,
+        defaultTaskHeartbeatTimeout: str = ...,
+        defaultTaskList: "TaskListTypeDef" = ...,
+        defaultTaskPriority: str = ...,
+        defaultTaskScheduleToStartTimeout: str = ...,
+        defaultTaskScheduleToCloseTimeout: str = ...
     ) -> None:
         """
         Registers a new *activity type* along with its configuration settings in the
         specified domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.register_activity_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.register_activity_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#register_activity_type)
         """
 
@@ -425,13 +425,13 @@ class SWFClient(BaseClient):
         *,
         name: str,
         workflowExecutionRetentionPeriodInDays: str,
-        description: str = None,
-        tags: List["ResourceTagTypeDef"] = None
+        description: str = ...,
+        tags: Sequence["ResourceTagTypeDef"] = ...
     ) -> None:
         """
         Registers a new domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.register_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.register_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#register_domain)
         """
 
@@ -441,59 +441,59 @@ class SWFClient(BaseClient):
         domain: str,
         name: str,
         version: str,
-        description: str = None,
-        defaultTaskStartToCloseTimeout: str = None,
-        defaultExecutionStartToCloseTimeout: str = None,
-        defaultTaskList: "TaskListTypeDef" = None,
-        defaultTaskPriority: str = None,
-        defaultChildPolicy: ChildPolicyType = None,
-        defaultLambdaRole: str = None
+        description: str = ...,
+        defaultTaskStartToCloseTimeout: str = ...,
+        defaultExecutionStartToCloseTimeout: str = ...,
+        defaultTaskList: "TaskListTypeDef" = ...,
+        defaultTaskPriority: str = ...,
+        defaultChildPolicy: ChildPolicyType = ...,
+        defaultLambdaRole: str = ...
     ) -> None:
         """
         Registers a new *workflow type* and its configuration settings in the specified
         domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.register_workflow_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.register_workflow_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#register_workflow_type)
         """
 
     def request_cancel_workflow_execution(
-        self, *, domain: str, workflowId: str, runId: str = None
+        self, *, domain: str, workflowId: str, runId: str = ...
     ) -> None:
         """
         Records a `WorkflowExecutionCancelRequested` event in the currently running
         workflow execution identified by the given domain, workflowId, and runId.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.request_cancel_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.request_cancel_workflow_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#request_cancel_workflow_execution)
         """
 
-    def respond_activity_task_canceled(self, *, taskToken: str, details: str = None) -> None:
+    def respond_activity_task_canceled(self, *, taskToken: str, details: str = ...) -> None:
         """
         Used by workers to tell the service that the  ActivityTask identified by the
         `taskToken` was successfully canceled.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.respond_activity_task_canceled)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.respond_activity_task_canceled)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#respond_activity_task_canceled)
         """
 
-    def respond_activity_task_completed(self, *, taskToken: str, result: str = None) -> None:
+    def respond_activity_task_completed(self, *, taskToken: str, result: str = ...) -> None:
         """
         Used by workers to tell the service that the  ActivityTask identified by the
         `taskToken` completed successfully with a `result` (if provided).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.respond_activity_task_completed)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.respond_activity_task_completed)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#respond_activity_task_completed)
         """
 
     def respond_activity_task_failed(
-        self, *, taskToken: str, reason: str = None, details: str = None
+        self, *, taskToken: str, reason: str = ..., details: str = ...
     ) -> None:
         """
         Used by workers to tell the service that the  ActivityTask identified by the
         `taskToken` has failed with `reason` (if specified).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.respond_activity_task_failed)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.respond_activity_task_failed)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#respond_activity_task_failed)
         """
 
@@ -501,26 +501,26 @@ class SWFClient(BaseClient):
         self,
         *,
         taskToken: str,
-        decisions: List["DecisionTypeDef"] = None,
-        executionContext: str = None
+        decisions: Sequence["DecisionTypeDef"] = ...,
+        executionContext: str = ...
     ) -> None:
         """
         Used by deciders to tell the service that the  DecisionTask identified by the
         `taskToken` has successfully completed.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.respond_decision_task_completed)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.respond_decision_task_completed)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#respond_decision_task_completed)
         """
 
     def signal_workflow_execution(
-        self, *, domain: str, workflowId: str, signalName: str, runId: str = None, input: str = None
+        self, *, domain: str, workflowId: str, signalName: str, runId: str = ..., input: str = ...
     ) -> None:
         """
         Records a `WorkflowExecutionSignaled` event in the workflow execution history
         and creates a decision task for the workflow execution identified by the given
         domain, workflowId and runId.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.signal_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.signal_workflow_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#signal_workflow_execution)
         """
 
@@ -530,28 +530,28 @@ class SWFClient(BaseClient):
         domain: str,
         workflowId: str,
         workflowType: "WorkflowTypeTypeDef",
-        taskList: "TaskListTypeDef" = None,
-        taskPriority: str = None,
-        input: str = None,
-        executionStartToCloseTimeout: str = None,
-        tagList: List[str] = None,
-        taskStartToCloseTimeout: str = None,
-        childPolicy: ChildPolicyType = None,
-        lambdaRole: str = None
+        taskList: "TaskListTypeDef" = ...,
+        taskPriority: str = ...,
+        input: str = ...,
+        executionStartToCloseTimeout: str = ...,
+        tagList: Sequence[str] = ...,
+        taskStartToCloseTimeout: str = ...,
+        childPolicy: ChildPolicyType = ...,
+        lambdaRole: str = ...
     ) -> RunTypeDef:
         """
         Starts an execution of the workflow type in the specified domain using the
         provided `workflowId` and input data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.start_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.start_workflow_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#start_workflow_execution)
         """
 
-    def tag_resource(self, *, resourceArn: str, tags: List["ResourceTagTypeDef"]) -> None:
+    def tag_resource(self, *, resourceArn: str, tags: Sequence["ResourceTagTypeDef"]) -> None:
         """
         Add a tag to a Amazon SWF domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#tag_resource)
         """
 
@@ -560,16 +560,16 @@ class SWFClient(BaseClient):
         *,
         domain: str,
         workflowId: str,
-        runId: str = None,
-        reason: str = None,
-        details: str = None,
-        childPolicy: ChildPolicyType = None
+        runId: str = ...,
+        reason: str = ...,
+        details: str = ...,
+        childPolicy: ChildPolicyType = ...
     ) -> None:
         """
         Records a `WorkflowExecutionTerminated` event and forces closure of the workflow
         execution identified by the given domain, runId, and workflowId.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.terminate_workflow_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.terminate_workflow_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#terminate_workflow_execution)
         """
 
@@ -579,7 +579,7 @@ class SWFClient(BaseClient):
         """
         Undeprecates a previously deprecated *activity type*.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.undeprecate_activity_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.undeprecate_activity_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#undeprecate_activity_type)
         """
 
@@ -587,7 +587,7 @@ class SWFClient(BaseClient):
         """
         Undeprecates a previously deprecated domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.undeprecate_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.undeprecate_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#undeprecate_domain)
         """
 
@@ -597,15 +597,15 @@ class SWFClient(BaseClient):
         """
         Undeprecates a previously deprecated *workflow type*.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.undeprecate_workflow_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.undeprecate_workflow_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#undeprecate_workflow_type)
         """
 
-    def untag_resource(self, *, resourceArn: str, tagKeys: List[str]) -> None:
+    def untag_resource(self, *, resourceArn: str, tagKeys: Sequence[str]) -> None:
         """
         Remove a tag from a Amazon SWF domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/client.html#untag_resource)
         """
 
@@ -614,7 +614,7 @@ class SWFClient(BaseClient):
         self, operation_name: Literal["get_workflow_execution_history"]
     ) -> GetWorkflowExecutionHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#getworkflowexecutionhistorypaginator)
         """
 
@@ -623,7 +623,7 @@ class SWFClient(BaseClient):
         self, operation_name: Literal["list_activity_types"]
     ) -> ListActivityTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listactivitytypespaginator)
         """
 
@@ -632,14 +632,14 @@ class SWFClient(BaseClient):
         self, operation_name: Literal["list_closed_workflow_executions"]
     ) -> ListClosedWorkflowExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listclosedworkflowexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_domains"]) -> ListDomainsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListDomains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListDomains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listdomainspaginator)
         """
 
@@ -648,7 +648,7 @@ class SWFClient(BaseClient):
         self, operation_name: Literal["list_open_workflow_executions"]
     ) -> ListOpenWorkflowExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listopenworkflowexecutionspaginator)
         """
 
@@ -657,7 +657,7 @@ class SWFClient(BaseClient):
         self, operation_name: Literal["list_workflow_types"]
     ) -> ListWorkflowTypesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listworkflowtypespaginator)
         """
 
@@ -666,6 +666,6 @@ class SWFClient(BaseClient):
         self, operation_name: Literal["poll_for_decision_task"]
     ) -> PollForDecisionTaskPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#pollfordecisiontaskpaginator)
         """
