@@ -30,8 +30,9 @@ Usage::
     poll_for_decision_task_paginator: PollForDecisionTaskPaginator = client.get_paginator("poll_for_decision_task")
     ```
 """
-from typing import Iterator
+from typing import Generic, Iterator, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import RegistrationStatusType
@@ -63,9 +64,19 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class GetWorkflowExecutionHistoryPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#getworkflowexecutionhistorypaginator)
     """
 
@@ -74,18 +85,18 @@ class GetWorkflowExecutionHistoryPaginator(Boto3Paginator):
         *,
         domain: str,
         execution: "WorkflowExecutionTypeDef",
-        reverseOrder: bool = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[HistoryTypeDef]:
+        reverseOrder: bool = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[HistoryTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.GetWorkflowExecutionHistory.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#getworkflowexecutionhistorypaginator)
         """
 
 
 class ListActivityTypesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListActivityTypes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listactivitytypespaginator)
     """
 
@@ -94,19 +105,19 @@ class ListActivityTypesPaginator(Boto3Paginator):
         *,
         domain: str,
         registrationStatus: RegistrationStatusType,
-        name: str = None,
-        reverseOrder: bool = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ActivityTypeInfosTypeDef]:
+        name: str = ...,
+        reverseOrder: bool = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ActivityTypeInfosTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListActivityTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListActivityTypes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listactivitytypespaginator)
         """
 
 
 class ListClosedWorkflowExecutionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listclosedworkflowexecutionspaginator)
     """
 
@@ -114,24 +125,24 @@ class ListClosedWorkflowExecutionsPaginator(Boto3Paginator):
         self,
         *,
         domain: str,
-        startTimeFilter: "ExecutionTimeFilterTypeDef" = None,
-        closeTimeFilter: "ExecutionTimeFilterTypeDef" = None,
-        executionFilter: "WorkflowExecutionFilterTypeDef" = None,
-        closeStatusFilter: "CloseStatusFilterTypeDef" = None,
-        typeFilter: "WorkflowTypeFilterTypeDef" = None,
-        tagFilter: "TagFilterTypeDef" = None,
-        reverseOrder: bool = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[WorkflowExecutionInfosTypeDef]:
+        startTimeFilter: "ExecutionTimeFilterTypeDef" = ...,
+        closeTimeFilter: "ExecutionTimeFilterTypeDef" = ...,
+        executionFilter: "WorkflowExecutionFilterTypeDef" = ...,
+        closeStatusFilter: "CloseStatusFilterTypeDef" = ...,
+        typeFilter: "WorkflowTypeFilterTypeDef" = ...,
+        tagFilter: "TagFilterTypeDef" = ...,
+        reverseOrder: bool = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[WorkflowExecutionInfosTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListClosedWorkflowExecutions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listclosedworkflowexecutionspaginator)
         """
 
 
 class ListDomainsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListDomains)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListDomains)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listdomainspaginator)
     """
 
@@ -139,18 +150,18 @@ class ListDomainsPaginator(Boto3Paginator):
         self,
         *,
         registrationStatus: RegistrationStatusType,
-        reverseOrder: bool = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DomainInfosTypeDef]:
+        reverseOrder: bool = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DomainInfosTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListDomains.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListDomains.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listdomainspaginator)
         """
 
 
 class ListOpenWorkflowExecutionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listopenworkflowexecutionspaginator)
     """
 
@@ -159,21 +170,21 @@ class ListOpenWorkflowExecutionsPaginator(Boto3Paginator):
         *,
         domain: str,
         startTimeFilter: "ExecutionTimeFilterTypeDef",
-        typeFilter: "WorkflowTypeFilterTypeDef" = None,
-        tagFilter: "TagFilterTypeDef" = None,
-        reverseOrder: bool = None,
-        executionFilter: "WorkflowExecutionFilterTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[WorkflowExecutionInfosTypeDef]:
+        typeFilter: "WorkflowTypeFilterTypeDef" = ...,
+        tagFilter: "TagFilterTypeDef" = ...,
+        reverseOrder: bool = ...,
+        executionFilter: "WorkflowExecutionFilterTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[WorkflowExecutionInfosTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListOpenWorkflowExecutions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listopenworkflowexecutionspaginator)
         """
 
 
 class ListWorkflowTypesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listworkflowtypespaginator)
     """
 
@@ -182,19 +193,19 @@ class ListWorkflowTypesPaginator(Boto3Paginator):
         *,
         domain: str,
         registrationStatus: RegistrationStatusType,
-        name: str = None,
-        reverseOrder: bool = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[WorkflowTypeInfosTypeDef]:
+        name: str = ...,
+        reverseOrder: bool = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[WorkflowTypeInfosTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.ListWorkflowTypes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#listworkflowtypespaginator)
         """
 
 
 class PollForDecisionTaskPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.PollForDecisionTask)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#pollfordecisiontaskpaginator)
     """
 
@@ -203,11 +214,11 @@ class PollForDecisionTaskPaginator(Boto3Paginator):
         *,
         domain: str,
         taskList: "TaskListTypeDef",
-        identity: str = None,
-        reverseOrder: bool = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DecisionTaskTypeDef]:
+        identity: str = ...,
+        reverseOrder: bool = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[DecisionTaskTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.5/reference/services/swf.html#SWF.Paginator.PollForDecisionTask.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.61/reference/services/swf.html#SWF.Paginator.PollForDecisionTask.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_swf/paginators.html#pollfordecisiontaskpaginator)
         """
