@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import (
     ActivityTaskTimeoutTypeType,
@@ -602,7 +602,7 @@ ContinueAsNewWorkflowExecutionDecisionAttributesTypeDef = TypedDict(
         "taskPriority": str,
         "taskStartToCloseTimeout": str,
         "childPolicy": ChildPolicyType,
-        "tagList": List[str],
+        "tagList": Sequence[str],
         "workflowTypeVersion": str,
         "lambdaRole": str,
     },
@@ -1499,7 +1499,7 @@ _OptionalRegisterDomainInputRequestTypeDef = TypedDict(
     "_OptionalRegisterDomainInputRequestTypeDef",
     {
         "description": str,
-        "tags": List["ResourceTagTypeDef"],
+        "tags": Sequence["ResourceTagTypeDef"],
     },
     total=False,
 )
@@ -1748,7 +1748,7 @@ _RequiredRespondDecisionTaskCompletedInputRequestTypeDef = TypedDict(
 _OptionalRespondDecisionTaskCompletedInputRequestTypeDef = TypedDict(
     "_OptionalRespondDecisionTaskCompletedInputRequestTypeDef",
     {
-        "decisions": List["DecisionTypeDef"],
+        "decisions": Sequence["DecisionTypeDef"],
         "executionContext": str,
     },
     total=False,
@@ -1975,7 +1975,7 @@ _OptionalStartChildWorkflowExecutionDecisionAttributesTypeDef = TypedDict(
         "taskPriority": str,
         "taskStartToCloseTimeout": str,
         "childPolicy": ChildPolicyType,
-        "tagList": List[str],
+        "tagList": Sequence[str],
         "lambdaRole": str,
     },
     total=False,
@@ -2103,7 +2103,7 @@ _OptionalStartWorkflowExecutionInputRequestTypeDef = TypedDict(
         "taskPriority": str,
         "input": str,
         "executionStartToCloseTimeout": str,
-        "tagList": List[str],
+        "tagList": Sequence[str],
         "taskStartToCloseTimeout": str,
         "childPolicy": ChildPolicyType,
         "lambdaRole": str,
@@ -2130,7 +2130,7 @@ TagResourceInputRequestTypeDef = TypedDict(
     "TagResourceInputRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": List["ResourceTagTypeDef"],
+        "tags": Sequence["ResourceTagTypeDef"],
     },
 )
 
@@ -2234,7 +2234,7 @@ UntagResourceInputRequestTypeDef = TypedDict(
     "UntagResourceInputRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
